/*
 * Copyright (c) 2011 RWTH Aachen University
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation;
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Author: Hendrik vom Lehn <vomlehn@cs.rwth-aachen.de>
 */

#include <stdlib.h>
#include <sys/ioctl.h> 
#include <sys/types.h>
#include <sys/socket.h>
#include <string.h>
#include <linux/wireless.h>
#include <stdio.h>

int main(int argc, char** argv) {
  int sock;
  struct iwreq wrq;
  int err;

  // get device name
  if(argc != 2)
  {
    printf("Please supply the device name as parameter\n");
    return 1;
  }
  strncpy(wrq.ifr_name, argv[1], sizeof(wrq.ifr_name));

  // open socket
  sock = socket(AF_INET, SOCK_DGRAM, 0);
  if(sock == -1) {
    printf("Could not open socket\n");
    return 1;
  }

  // perform ioctl
  err = ioctl(sock, SIOCIWFIRSTPRIV+1, &wrq);
  if(err < 0) {
    printf("ioctl failed: %s\n", strerror(-err));
    return 1;
  }

  // retrieve FER
  printf("Current FER of %s: %hhu\n", argv[1], *(wrq.u.name));
  
}

